function h_plot(fname,elev,azim,n)
% h_plot(fname,elev,azim[,n])
%
% Plot the HRTF. If the HRTF is stored in time domain, then
% it will be optionally cropped to to n points. ITD is also
% restored in time domain data if ITD has been extracted.
%
% Copyright (c) 2006 Wave Arts, Inc.
% Written by Bill Gardner
%

hinfo = h_open(fname);
fs = h_get_fs(hinfo);

[x, itd] = h_read(hinfo,elev,azim);
hL = x(1,:);
hR = x(2,:);

if h_is_freq(hinfo)
	%
	% Frequency domain
	%
	n = h_get_len(hinfo);
	freq = (0 : n/2) * fs / n;
	figure
	semilogx(freq,20*log10(abs(hL(1:(n/2 + 1)))),'g');
	hold on
	semilogx(freq,20*log10(abs(hR(1:(n/2 + 1)))),'r:');
	grid
	axis([20 20000 -40 10]);
	title(sprintf('HRTF %s at (%d,%d): left solid, right dotted',titlestr(fname),azim,elev));
	ylabel('dB');
	xlabel('freq, Hz');

	if 0
	%
	% Linear freq axis
	%
	nplot = getinput('number points to plot',n/2 + 1);
	figure
	plot(freq(1:nplot),20*log10(abs(hL(1:nplot))),'g');
	hold on
	plot(freq(1:nplot),20*log10(abs(hR(1:nplot))),'r--');
	grid
	title(sprintf('HRTF %s at (%d,%d): left solid, right dashed',titlestr(fname),azim,elev));
	ylabel('dB');
	xlabel('freq, Hz');
	end
else
	%
	% Time domain HRTF
	%
	if nargin < 4
		n = h_get_len(hinfo);
	end

	%
	% Crop and delay by ITD
	%
	hL = crop(hL,n);
	hR = crop(hR,n);
	if h_is_itdex(hinfo)
		if itd >= 0
			hL = lag_delay(hL, itd);
		else
			hR = lag_delay(hR, -itd);
		end
	end
	
	figure
	plot(hL,'g');
	hold on
	plot(hR,'r--');
	title(sprintf('HRTF %s at (%d,%d): left solid, right dashed',titlestr(fname),azim,elev));
	
	figure
	plotmaglogf(hL,'g',fs,1024);
	hold on
	plotmaglogf(hR,'r--',fs,1024);
	axis([20 20000 -40 10]);
	title(sprintf('HRTF %s at (%d,%d): left solid, right dashed',titlestr(fname),azim,elev));
	grid on
end

h_close(hinfo)
