function h_save_hdr(fname, hinfo, itds, elevs)
% h_save_hdr(fname, hinfo, itds, elevs)
%
% Save HRTF header info into ASCII file fname.txt. Also see
% h_load_hdr for function that loads header files.
%
% Format of file:
%
% fs n_elevs n_hrtfs flags num_b_coeff num_a_coeff
% elevs(1,:)
% elevs(2,:)
% itd(1)
% itd(2)
% ...
% itd(n_hrtf)
%
% ITDs are only saved if the ITD flag is set in flags. Comments
% in file indicated by line starting with '%'.
%
% Copyright (c) 2006 Wave Arts, Inc.
% Written by Bill Gardner
%

path = h_path(fname);
fullname = sprintf('%s.txt',path);

%
% Get flags in readable form
%
sym_str = '';
itdex_str = '';
freq_str = '';
if h_is_sym(hinfo)
	sym_str = ' symmetric';
end
if h_is_itdex(hinfo)
	itdex_str = ' ITD_extracted';
end
if h_is_freq(hinfo)
	freq_str = ' freq_domain';
end
flagstr = sprintf('%s%s%s', sym_str, itdex_str, freq_str);

fp = fopen(fullname,'wt+');
if (fp == -1)
	error(sprintf('cannot create HRTF header file %s',fullname));
end
fprintf(fp,'%% fs n_elevs n_hrtfs flags num_b_coeff num_a_coeff\n');
fprintf(fp,'%% flags: %s\n',flagstr);
fprintf(fp,'%d %d %d %d %d %d\n', ...
	hinfo(2), hinfo(3), hinfo(4), hinfo(5), hinfo(6), hinfo(7));
fprintf(fp,'%% elevs(1,:)\n');
fprintf(fp,'%d ',elevs(1,:));
fprintf(fp,'\n');
fprintf(fp,'%% elevs(2,:)\n');
fprintf(fp,'%d ',elevs(2,:));
fprintf(fp,'\n');
if h_is_itdex(hinfo)
	fprintf(fp,'%% ITDs(1...n_hrtf)\n');
	fprintf(fp,'%f\n',itds);
end
fclose(fp);
